=== modified file 'drizzled/identifier/schema.cc'
--- drizzled/identifier/schema.cc	2010-09-23 01:53:13 +0000
+++ drizzled/identifier/schema.cc	2010-10-20 01:42:35 +0000
@@ -27,6 +27,8 @@
 #include "drizzled/current_session.h"
 #include "drizzled/internal/my_sys.h"
 
+#include "drizzled/util/backtrace.h"
+
 #include <algorithm>
 #include <sstream>
 #include <cstdio>
@@ -121,8 +123,19 @@
 
 SchemaIdentifier::SchemaIdentifier(const std::string &db_arg) :
   db(db_arg),
-  db_path("")
+  db_path(""),
+  catalog("LOCAL")
 { 
+#if 0
+  string::size_type lastPos= db.find_first_of('/', 0);
+
+  if (lastPos != std::string::npos) 
+  {
+    catalog= db.substr(0, lastPos);
+    db.erase(0, lastPos + 1);
+  }
+#endif
+
   if (not db_arg.empty())
   {
     drizzled::build_schema_filename(db_path, db);

=== modified file 'drizzled/identifier/schema.h'
--- drizzled/identifier/schema.h	2010-08-05 20:24:49 +0000
+++ drizzled/identifier/schema.h	2010-10-20 01:42:35 +0000
@@ -49,12 +49,13 @@
 
 namespace drizzled {
 
-static std::string catalog("");
+static std::string catalog("local");
 
 class SchemaIdentifier
 {
   std::string db;
   std::string db_path;
+  std::string catalog;
 
 
   // @note this should be changed to protected once Session contains an
@@ -92,6 +93,8 @@
                                   SchemaIdentifier &identifier)
   {
     output << "SchemaIdentifier:(";
+    output <<  identifier.catalog;
+    output << ", ";
     output <<  identifier.db;
     output << ", ";
     output << identifier.getPath();

=== modified file 'drizzled/signal_handler.cc'
--- drizzled/signal_handler.cc	2010-10-10 08:28:30 +0000
+++ drizzled/signal_handler.cc	2010-10-20 01:42:35 +0000
@@ -29,12 +29,7 @@
 #include "drizzled/plugin.h"
 #include "drizzled/plugin/scheduler.h"
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-#include <execinfo.h>
-#include <cxxabi.h>
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+#include "drizzled/util/backtrace.h"
 
 using namespace drizzled;
 
@@ -101,7 +96,6 @@
 #endif
 }
 
-#define BACKTRACE_STACK_SIZE 50
 void drizzled_handle_segfault(int sig)
 {
   time_t curr_time;
@@ -151,65 +145,7 @@
                     "Hope that's ok; if not, decrease some variables in the "
                     "equation.\n\n"));
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-  {
-    void *array[BACKTRACE_STACK_SIZE];
-    size_t size;
-    char **strings;
-
-    size= backtrace(array, BACKTRACE_STACK_SIZE);
-    strings= backtrace_symbols(array, size);
-
-    std::cerr << "Number of stack frames obtained: " << size <<  std::endl;
-
-    for (size_t x= 1; x < size; x++) 
-    {
-      size_t sz= 200;
-      char *function= (char *)malloc(sz);
-      char *begin= 0;
-      char *end= 0;
-
-      for (char *j = strings[x]; *j; ++j)
-      {
-        if (*j == '(') {
-          begin = j;
-        }
-        else if (*j == '+') {
-          end = j;
-        }
-      }
-      if (begin && end)
-      {
-        begin++;
-        *end= '\0';
-
-        int status;
-        char *ret = abi::__cxa_demangle(begin, function, &sz, &status);
-        if (ret) 
-        {
-          function= ret;
-        }
-        else
-        {
-          std::strncpy(function, begin, sz);
-          std::strncat(function, "()", sz);
-          function[sz-1] = '\0';
-        }
-        std::cerr << function << std::endl;
-      }
-      else
-      {
-        std::cerr << strings[x] << std::endl;
-      }
-      free(function);
-    }
-
-
-    free (strings);
-  }
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+  drizzled::util::custom_backtrace();
 
   write_core(sig);
 

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-10-16 23:41:19 +0000
+++ drizzled/sql_parse.cc	2010-10-20 01:42:35 +0000
@@ -211,6 +211,8 @@
 
     SchemaIdentifier identifier(tmp);
 
+    std::cerr << identifier << "\n";
+
     if (not mysql_change_db(session, identifier))
     {
       session->my_ok();

=== added file 'drizzled/util/backtrace.cc'
--- drizzled/util/backtrace.cc	1970-01-01 00:00:00 +0000
+++ drizzled/util/backtrace.cc	2010-10-20 01:42:35 +0000
@@ -0,0 +1,100 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#include "config.h"
+#include "drizzled/util/backtrace.h"
+
+#include <string.h>
+#include <stdlib.h>
+#include <iostream>
+
+#ifdef __GNUC__
+#ifdef HAVE_BACKTRACE
+#include <execinfo.h>
+#include <cxxabi.h>
+#endif // HAVE_BACKTRACE
+#endif // __GNUC__
+
+
+namespace drizzled
+{
+namespace util
+{
+
+void custom_backtrace(void)
+{
+  void *array[50];
+  size_t size;
+  char **strings;
+
+  size= backtrace(array, 50);
+  strings= backtrace_symbols(array, size);
+
+  std::cerr << "Number of stack frames obtained: " << size <<  std::endl;
+
+  for (size_t x= 1; x < size; x++) 
+  {
+    size_t sz= 200;
+    char *function= (char *)malloc(sz);
+    char *begin= 0;
+    char *end= 0;
+
+    for (char *j = strings[x]; *j; ++j)
+    {
+      if (*j == '(') {
+        begin = j;
+      }
+      else if (*j == '+') {
+        end = j;
+      }
+    }
+    if (begin && end)
+    {
+      begin++;
+      *end= '\0';
+
+      int status;
+      char *ret = abi::__cxa_demangle(begin, function, &sz, &status);
+      if (ret) 
+      {
+        function= ret;
+      }
+      else
+      {
+        strncpy(function, begin, sz);
+        strncat(function, "()", sz);
+        function[sz-1] = '\0';
+      }
+      std::cerr << function << std::endl;
+    }
+    else
+    {
+      std::cerr << strings[x] << std::endl;
+    }
+    free(function);
+  }
+
+
+  free (strings);
+}
+
+} /* namespace util */
+} /* namespace drizzled */

=== added file 'drizzled/util/backtrace.h'
--- drizzled/util/backtrace.h	1970-01-01 00:00:00 +0000
+++ drizzled/util/backtrace.h	2010-10-20 01:42:35 +0000
@@ -0,0 +1,36 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_UTIL_BACKTRACE_H
+#define DRIZZLED_UTIL_BACKTRACE_H
+
+namespace drizzled
+{
+
+namespace util
+{
+
+void custom_backtrace(void);
+
+} /* namespace util */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_UTIL_BACKTRACE_H */
+

=== modified file 'drizzled/util/include.am'
--- drizzled/util/include.am	2010-10-02 21:15:42 +0000
+++ drizzled/util/include.am	2010-10-20 01:42:35 +0000
@@ -15,6 +15,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 nobase_dist_include_HEADERS+= \
+                              drizzled/util/backtrace.h \
                               drizzled/util/convert.h \
                               drizzled/util/functors.h \
 			      drizzled/util/storable.h \
@@ -23,5 +24,7 @@
                               drizzled/util/tokenize.h
 
 noinst_LTLIBRARIES+= drizzled/util/libutil.la
-drizzled_util_libutil_la_SOURCES= drizzled/util/convert.cc
+drizzled_util_libutil_la_SOURCES= \
+                                  drizzled/util/backtrace.cc \
+                                  drizzled/util/convert.cc
 

=== modified file 'plugin/information_schema_dictionary/tests/r/tables.result'
--- plugin/information_schema_dictionary/tests/r/tables.result	2010-10-15 20:54:21 +0000
+++ plugin/information_schema_dictionary/tests/r/tables.result	2010-10-20 01:42:35 +0000
@@ -6,71 +6,71 @@
 	test				
 select * from INFORMATION_SCHEMA.TABLES;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 use information_schema;
 show schemas;
 Database
@@ -80,71 +80,71 @@
 test
 select * from INFORMATION_SCHEMA.TABLES;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG=NULL;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA=NULL;
@@ -155,93 +155,93 @@
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="information_schema" AND TABLE_TYPE="VIEW";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 select * from INFORMATION_SCHEMA.TABLES ORDER BY TABLE_SCHEMA, TABLE_NAME;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 create schema a;
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
@@ -262,75 +262,75 @@
 ds
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
+LOCAL	a	a	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "a%";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
-	a	aa	BASE
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "%a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	a	a	BASE
-	a	aa	BASE
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "%s";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	a	ds	BASE
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	a	ds	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a" ORDER BY TABLE_NAME;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
-	a	aa	BASE
-	a	b	BASE
-	a	c	BASE
-	a	d	BASE
-	a	ds	BASE
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
+LOCAL	a	b	BASE
+LOCAL	a	c	BASE
+LOCAL	a	d	BASE
+LOCAL	a	ds	BASE
 drop schema a;
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE

